@@ -40,14 +40,12 @@ for my $name ( keys $ANSI->%* ) {
 }
 
 our $EXPORT = {
-    CORE    => [qw[$MSWIN $CRLF $LF $EMPTY $SPACE]],
+    CORE    => [qw[$MSWIN $EMPTY $SPACE]],
     DEFAULT => [':CORE'],
     ANSI    => [ map { '$' . $_ } keys $ANSI->%* ],
 };
 
 const our $MSWIN => $^O =~ /MSWin/sm ? 1 : 0;
-const our $CRLF  => qq[\x0D\x0A];                           ## no critic qw[ValuesAndExpressions::ProhibitEscapedCharacters]
-const our $LF    => qq[\x0A];                               ## no critic qw[ValuesAndExpressions::ProhibitEscapedCharacters]
 const our $EMPTY => q[];
 const our $SPACE => q[ ];
 
